#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Ejemplo de lectura de archivo de photogate y procesamiento de datos

"""

# Importamos librerías estándares

from numpy import *
import matplotlib.pyplot as plt

#%% Histograma con todas sus partes

def lector(x):
    "Transforma las comas en puntos"
    return float(x.decode().replace(',','.'))

datos = genfromtxt('DATOS_PHOTOGATE.txt',skip_header=4,converters={0:lector, 1:lector})

# La columna 0 es el tiempo
tiempo = datos[:,0]

# La columna 1 es el voltaje
volts  = datos[:,1]

#%% Grafico los datos en crudo

plt.figure(1)
plt.plot( tiempo, volts )
plt.grid(True,ls=':')
plt.xlabel('tiempo [s]')
plt.ylabel('señal [V]')
plt.tight_layout()

plt.savefig('photogate_señal.png')
plt.savefig('photogate_señal.svg')

#%% ejemplo de cálculo de derivada numérica

# Cálculo de derivada
derivada = diff(volts)/diff(tiempo)

# Defino un umbral
umbral   = 300

# Extraigo INDICES de flanco de subida
I_subida = derivada > umbral

# Busco los tiempos de esos índices
tiempos_subida = tiempo[:-1][I_subida]

print(tiempos_subida)

# Me fijo las diferencias
print( diff(tiempos_subida) )

plt.figure(2)

# Grafico Volts en función del tiempo
plt.subplot(2,1,1)
plt.plot( tiempo, volts )
plt.grid(True,ls=':')
# plt.xlabel('tiempo [s]')
plt.ylabel('señal [V]')
plt.gca().set_xticklabels([])

# Grafico la derivada y el umbral
plt.subplot(2,1,2)
plt.plot( tiempo[:-1], derivada , label='derivada')
plt.axhline(umbral, color='red', ls='--', label='umbral')

# Agrego puntitos en los tiempos de flanco detectados
plt.plot( tiempos_subida , derivada[I_subida] , 'o', label='flancos detectados')

plt.grid(True,ls=':')
plt.xlabel('tiempo [s]')
plt.ylabel('derivada [V/s]')
plt.legend()

# Agrego puntitos en los tiempos de flanco detectados del primer subplot
plt.subplot(2,1,1)
plt.plot( tiempos_subida , volts[:-1][I_subida] , 'o', label='flancos detectados')
